==> tutti-ui-swing-1.0-sources.jar: fr/ifremer/tutti/ui/swing/content/operation/catches/species/SelectSpeciesUIModel.java <==

package fr.ifremer.tutti.ui.swing.content.operation.catches.species;

/*
 * #%L
 * Tutti :: UI
 * $Id: SelectSpeciesUIModel.java 341 2013-02-05 21:53:25Z kmorin $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.0/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/operation/catches/species/SelectSpeciesUIModel.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.collect.Lists;
import fr.ifremer.tutti.persistence.entities.referential.Species;
import fr.ifremer.tutti.ui.swing.AbstractTuttiBeanUIModel;

import java.util.List;

/**
 * @author kmorin <kmorin@codelutin.com>
 * @since 1.0
 */
public class SelectSpeciesUIModel extends AbstractTuttiBeanUIModel<SelectSpeciesUIModel, SelectSpeciesUIModel> {

    public static final String PROPERTY_SPECIES = "species";

    public static final String PROPERTY_SELECTED_SPECIES = "selectedSpecies";

    protected List<Species> species = Lists.newArrayList();

    protected Species selectedSpecies;

    public SelectSpeciesUIModel() {
        super(SelectSpeciesUIModel.class, null, null);
    }

    public List<Species> getSpecies() {
        return species;
    }

    public void setSpecies(List<Species> species) {
        Object oldValue = getSpecies();
        this.species = Lists.newArrayList(species);
        firePropertyChange(PROPERTY_SPECIES, oldValue, this.species);
    }

    public Species getSelectedSpecies() {
        return selectedSpecies;
    }

    public void setSelectedSpecies(Species selectedSpecies) {
        Object oldValue = getSelectedSpecies();
        this.selectedSpecies = selectedSpecies;
        firePropertyChange(PROPERTY_SELECTED_SPECIES, oldValue, selectedSpecies);
    }

}

==> tutti-ui-swing-1.0.1-sources.jar: fr/ifremer/tutti/ui/swing/content/operation/catches/species/SelectSpeciesUIModel.java <==

package fr.ifremer.tutti.ui.swing.content.operation.catches.species;

/*
 * #%L
 * Tutti :: UI
 * $Id: SelectSpeciesUIModel.java 341 2013-02-05 21:53:25Z kmorin $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.0.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/operation/catches/species/SelectSpeciesUIModel.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.collect.Lists;
import fr.ifremer.tutti.persistence.entities.referential.Species;
import fr.ifremer.tutti.ui.swing.AbstractTuttiBeanUIModel;

import java.util.List;

/**
 * @author kmorin <kmorin@codelutin.com>
 * @since 1.0
 */
public class SelectSpeciesUIModel extends AbstractTuttiBeanUIModel<SelectSpeciesUIModel, SelectSpeciesUIModel> {

    public static final String PROPERTY_SPECIES = "species";

    public static final String PROPERTY_SELECTED_SPECIES = "selectedSpecies";

    protected List<Species> species = Lists.newArrayList();

    protected Species selectedSpecies;

    public SelectSpeciesUIModel() {
        super(SelectSpeciesUIModel.class, null, null);
    }

    public List<Species> getSpecies() {
        return species;
    }

    public void setSpecies(List<Species> species) {
        Object oldValue = getSpecies();
        this.species = Lists.newArrayList(species);
        firePropertyChange(PROPERTY_SPECIES, oldValue, this.species);
    }

    public Species getSelectedSpecies() {
        return selectedSpecies;
    }

    public void setSelectedSpecies(Species selectedSpecies) {
        Object oldValue = getSelectedSpecies();
        this.selectedSpecies = selectedSpecies;
        firePropertyChange(PROPERTY_SELECTED_SPECIES, oldValue, selectedSpecies);
    }

}
